===========
The "menuplaceholder" app: menu placeholders for Mezzanine
===========

About
-----

The **menuplaceholder** application is for adding placeholder menus items to
Mezzanine.

Installation and Dependencies
-----------------------------

Django and Mezzanine

History
-------


Copyright
---------

Copyright (c) 2017
`Peter Murphy <http://www.pkmurphy.com.au/>`_
<peterkmurphy@gmail.com>.
